@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack import format
 from openstack.network import network_service
 from openstack import resource
 
@@ -36,10 +35,11 @@ class Network(resource.Resource):
     #: *Type: list of availability zone names*
     availability_zones = resource.prop('availability_zones')
     #: Timestamp when the network was created.
-    #: *Type: datetime object parsed from ISO 8601 formatted string*
-    created_at = resource.prop('created_at', type=format.ISO8601)
+    created_at = resource.prop('created_at')
     #: The network description.
     description = resource.prop('description')
+    #: DNS Domain for the network
+    dns_domain = resource.prop('dns_domain')
     #: The ID of the IPv4 address scope for the network.
     ipv4_address_scope_id = resource.prop('ipv4_address_scope')
     #: The ID of the IPv6 address scope for the network.
@@ -78,6 +78,8 @@ class Network(resource.Resource):
     #: An isolated segment ID on the physical network. The provider
     #: network type defines the segmentation model.
     provider_segmentation_id = resource.prop('provider:segmentation_id')
+    #: Revision number of the network. *Type: int*
+    revision_number = resource.prop('revision_number', type=int)
     segments = resource.prop('segments')
     #: The network status.
     status = resource.prop('status')
@@ -85,5 +87,4 @@ class Network(resource.Resource):
     #: *Type: list of strs of the subnet IDs*
     subnet_ids = resource.prop('subnets', type=list)
     #: Timestamp when the network was last updated.
-    #: *Type: datetime object parsed from ISO 8601 formatted string*
-    updated_at = resource.prop('updated_at', type=format.ISO8601)
+    updated_at = resource.prop('updated_at')
