@@ -350,7 +350,10 @@ class TestQueryParameters(base.TestCase):
 
         sot = resource2.QueryParameters(location, **mapping)
 
-        self.assertEqual({"location": "location", "first_name": "first-name"},
+        self.assertEqual({"location": "location",
+                          "first_name": "first-name",
+                          "limit": "limit",
+                          "marker": "marker"},
                          sot._mapping)
 
     def test_transpose_unmapped(self):
@@ -382,7 +385,7 @@ class TestResource(base.TestCase):
 
     def test_initialize_basic(self):
         body = {"body": 1}
-        header = {"header": 2}
+        header = {"header": 2, "Location": "somewhere"}
         uri = {"uri": 3}
         everything = dict(itertools.chain(body.items(), header.items(),
                                           uri.items()))
@@ -394,6 +397,7 @@ class TestResource(base.TestCase):
                                "_collect_attrs", mock_collect):
             sot = resource2.Resource(synchronized=False, **everything)
             mock_collect.assert_called_once_with(everything)
+        self.assertEqual("somewhere", sot.location)
 
         self.assertIsInstance(sot._body, resource2._ComponentManager)
         self.assertEqual(body, sot._body.dirty)
@@ -568,6 +572,31 @@ class TestResource(base.TestCase):
         self.assertIn("y", Test._uri_mapping())
         self.assertIn("z", Test._uri_mapping())
 
+    def test__getattribute__id_in_body(self):
+        id = "lol"
+        sot = resource2.Resource(id=id)
+
+        result = getattr(sot, "id")
+        self.assertEqual(result, id)
+
+    def test__getattribute__id_with_alternate(self):
+        id = "lol"
+
+        class Test(resource2.Resource):
+            blah = resource2.Body("blah", alternate_id=True)
+
+        sot = Test(blah=id)
+
+        result = getattr(sot, "id")
+        self.assertEqual(result, id)
+
+    def test__getattribute__id_without_alternate(self):
+        class Test(resource2.Resource):
+            id = None
+
+        sot = Test()
+        self.assertIsNone(sot.id)
+
     def test__alternate_id_None(self):
         self.assertEqual("", resource2.Resource._alternate_id())
 
